@@ -4,31 +4,21 @@ hio.core.http.serving classes
 
 nonblocking http server
 """
-
-
 import sys
 import os
-import socket
-import errno
 import io
-from collections import deque
-import codecs
 import json
-import ssl
 import copy
-import random
 import datetime
+import mimetypes
 
-from urllib.parse import urlsplit, quote, quote_plus, unquote, unquote_plus
-
-from  multidict import CIMultiDict as cimdict
-
+from urllib.parse import urlsplit, unquote
+from contextlib import contextmanager
 
 from ... import help
-from ...help import helping
-from ...base import tyming
+from ...base import doing
 from .. import tcp
-# from ..tcp import Server, ServerTls
+
 from . import httping
 
 logger = help.ogler.getLogger()
@@ -102,7 +92,7 @@ class Requestant(httping.Parsent):
         if self.headed:
             return  # already parsed the head
 
-        self.headers = helping.imdict()
+        self.headers = help.Hict()
 
         # create generator
         lineParser = httping.parseLine(raw=self.msg, eols=(CRLF, LF), kind="status line")
@@ -298,11 +288,12 @@ class Responder():
         self.closed = False  # True if connection closed by far side
         self.iterator = None  # iterator on application body
         self.status = status
-        self.headers = helping.imdict()  # headers
+        self.headers = help.Hict()  # headers
         self.length = None  # if content-length provided must not exceed
         self.size = 0  # number of body bytes sent so far
         self.evented = False  # True if response is event-stream
 
+
     def close(self):
         """
         Close any resources
@@ -312,6 +303,7 @@ class Responder():
         self.ended = True
         self.closed = True
 
+
     def reset(self, environ, chunkable=None):
         """
         Reset attributes for another request-response
@@ -327,10 +319,11 @@ class Responder():
         self.ended = False
         self.iterator = None
         self.status = "200 OK"
-        self.headers = helping.imdict()
+        self.headers = help.Hict()
         self.length = None
         self.size = 0
 
+
     def build(self):
         """
         Return built head bytes from .status and .headers
@@ -339,12 +332,14 @@ class Responder():
         lines = []
 
         _status = getattr(self.iterator, '_status', None)  # if AttributiveGenerator
-        status = _status if _status is not None else self.status  # override
+        if _status is not None:  # override
+            self.status = _status
 
-        if isinstance(status, int):
-            status = "{0} {1}".format(status, httping.STATUS_DESCRIPTIONS[status])
+        if isinstance(self.status, int):  # replace int with str
+            self.status = "{0} {1}".format(self.status,
+                                           httping.STATUS_DESCRIPTIONS[self.status])
 
-        startLine = "{0} {1}".format(self.HttpVersionString, status)
+        startLine = "{0} {1}".format(self.HttpVersionString, self.status)
         try:
             startLine = startLine.encode('ascii')
         except UnicodeEncodeError:
@@ -352,7 +347,7 @@ class Responder():
         lines.append(startLine)
 
         # Override if AttributiveGenerator
-        self.headers.update(getattr(self.iterator, '_headers', helping.imdict()))
+        self.headers.update(getattr(self.iterator, '_headers', help.Hict()))
 
         if u'server' not in self.headers:  # create Server header
             self.headers[u'server'] = "Ioflo WSGI Server"
@@ -372,6 +367,7 @@ class Responder():
 
         return head
 
+
     def write(self, msg):
         """
         WSGI write callback This writes out the headers the first time its called
@@ -397,13 +393,15 @@ class Responder():
         if msg:
             self.incomer.tx(msg)
 
+
     def start(self, status, response_headers, exc_info=None):
         """
         WSGI application start_response callable
 
         Parameters:
 
-        status is string of status code and status reason '200 OK'
+        status is string of status code and status reason '200 OK' or simple
+            status code int which will be replaced with string
 
         response_headers is list of tuples of strings of the form (field, value)
                           one tuple for each header example:
@@ -446,7 +444,7 @@ class Responder():
             raise AssertionError("Already started!")
 
         self.status = status
-        self.headers = helping.imdict(response_headers)
+        self.headers = help.Hict(response_headers)
 
         if u'content-length' in self.headers:
             self.length = int(self.headers['content-length'])
@@ -461,13 +459,15 @@ class Responder():
         self.started = True
         return self.write
 
+
     def service(self):
         """
         Service wsgi compatible application
         """
         if not self.closed and not self.ended:
             if self.iterator is None:  # initiate application
-                self.iterator = iter(self.app(self.environ, self.start))
+                self.iterator = iter(self.app(self.environ,
+                                              start_response=self.start))
             try:
                 msg = next(self.iterator)
             except StopIteration as ex:
@@ -477,7 +477,7 @@ class Responder():
                 self.ended = True
             except httping.HTTPError as ex:
                 if not self.headed:
-                    headers = helping.imdict()
+                    headers = help.Hict()
                     headers.update(ex.headers.items())
                     if 'content-type' not in headers:
                         headers['content-type'] = 'text/plain'
@@ -492,8 +492,7 @@ class Responder():
                     logger.error("HTTPError streaming body after headers sent.\n"
                                     "%s\n", ex)
             except Exception as ex:  # handle http exceptions not caught by app
-                logger.error("Unexcepted Server Error.\n"
-                                    "%s\n", ex)
+                logger.error("Unexcepted Server Error.\n%s\n", ex)
             else:
                 if msg:  # only write if not empty allows async processing
                     self.write(msg)
@@ -501,6 +500,36 @@ class Responder():
                         self.ended = True
 
 
+@contextmanager
+def openServer(cls=None, **kwa):
+    """
+    Wrapper to create and open HTTP Server instances
+    When used in with statement block, calls .close() on exit of with block
+
+    Parameters:
+        cls is Class instance of subclass instance
+
+    Usage:
+        with openServer() as server0:
+            server0.
+
+        with openServer(cls=BareServer) as server0:
+            server0.
+
+    """
+    cls = cls if cls is not None else Server
+
+    try:
+        server = cls(**kwa)
+        server.reopen()  #  opens accept socket
+
+        yield server
+
+    finally:
+        server.close()
+
+
+
 class Server():
     """
     Server WSGI HTTP Server Class
@@ -619,12 +648,23 @@ class Server():
         self.secured = secured
         self.servant = servant
 
-    def open(self):
+
+    def wind(self, tymth):
+        """
+        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
+        Updates winds .tymer .tymth
+        """
+        if self.servant:
+            self.servant.wind(tymth)
+
+
+    def reopen(self):
         """
         Return result of .servant.reopen()
         """
         return self.servant.reopen()
 
+
     def close(self):
         """
         Close all reqs, reps, and ixes
@@ -721,7 +761,7 @@ class Server():
         Timeout stale connections
         """
         self.servant.serviceConnects()
-        for ca, ix in self.servant.ixes.items():
+        for ca, ix in list(self.servant.ixes.items()):  # ixes changes during iteration
             if ix.cutoff:
                 self.closeConnection(ca)
                 continue
@@ -737,7 +777,7 @@ class Server():
         """
         Service pending requestants
         """
-        for ca, requestant in self.reqs.items():
+        for ca, requestant in list(self.reqs.items()):
             if requestant.parser:
                 try:
                     requestant.parse()
@@ -779,7 +819,7 @@ class Server():
         """
         Service pending responders
         """
-        for ca, responder in self.reps.items():
+        for ca, responder in list(self.reps.items()):
             if responder.closed:
                 self.closeConnection(ca)
                 continue
@@ -839,7 +879,7 @@ class CustomResponder():
         """
         self.steward = steward
         self.status = status
-        self.headers = helping.imdict(headers) if headers else helping.imdict()
+        self.headers = help.Hict(headers) if headers else help.Hict()
         if body and isinstance(body, str):  # use default
             # RFC 2616 Section 3.7.1 default charset of iso-8859-1.
             body = body.encode('iso-8859-1')
@@ -865,7 +905,7 @@ class CustomResponder():
         if status is not None:
             self.status = status
         if headers is not None:
-            self.headers = helping.imdict(headers)
+            self.headers = help.Hict(headers)
         if body is not None:  # body should be bytes
             if isinstance(body, str):
                 # RFC 2616 Section 3.7.1 default charset of iso-8859-1.
@@ -1114,11 +1154,17 @@ class BareServer():
                                  tymeout=timeout,
                                  **kwa)
 
-
         self.secured = secured
         self.servant = servant
 
 
+    def reopen(self):
+        """
+        Return result of .servant.reopen()
+        """
+        return self.servant.reopen()
+
+
     def idle(self):
         """
         Returns True if no connections have requests in process
@@ -1132,6 +1178,17 @@ class BareServer():
         return idle
 
 
+    def close(self):
+        """
+        Close all  ixes for all stewards
+        """
+        for ca, steward in list(self.stewards.items()):
+            self.closeConnection(ca)
+
+        # just in case there is an orphan ix
+        self.servant.close()
+
+
     def closeConnection(self, ca):
         """
         Close and remove connection and associated steward given by ca
@@ -1194,3 +1251,112 @@ class BareServer():
         self.serviceStewards()
         self.servant.serviceSendsAllIx()
 
+
+try:
+    import falcon
+
+except ImportError as ex:
+    logger.error("Falcon not available.\n")
+
+else:  # falcon import succeeded
+    class StaticSink():
+        """
+        Class that provides Falcon sink endpoint for serving static files in support
+        of a client side web app.
+
+        """
+        StaticSinkBasePath = "/static"
+        DefaultStaticSinkBasePath = "/"
+
+        def __init__(self, staticDirPath=None):
+            """
+            Parameters:
+               staticDirPath (str): path to static sink directory
+
+            Example computation of staticDirPath:
+
+            WEB_DIR_PATH = os.path.dirname(
+                                os.path.abspath(
+                                    sys.modules.get(__name__).__file__))
+            STATIC_DIR_PATH = os.path.join(WEB_DIR_PATH, 'static')
+
+            /Users/Load/Data/Code/public/hio/src/hio/demo/web/static
+            """
+            if staticDirPath is None:
+                staticDirPath == os.path.join(
+                                    os.path.dirname(
+                                        os.path.abspath(
+                                            sys.modules.get(__name__).__file__)),
+                                            self.StaticSinkBasePath[1:])
+            self.staticDirPath = staticDirPath
+
+        def __call__(self, req, rep):
+            path = req.path.removeprefix(self.StaticSinkBasePath)
+            path = path.removeprefix(self.DefaultStaticSinkBasePath)
+            if not path:  # return default
+                path = "index.html"
+            path = os.path.join(self.staticDirPath, path)
+            if not os.path.exists(path):
+                raise falcon.HTTPError(falcon.HTTP_NOT_FOUND,
+                                'Missing Resource',
+                                'File "{}" not found or forbidden'.format(path))
+            filetype = mimetypes.guess_type(path, strict=True)[0]  # get first guess
+            rep.set_header("Content-Type", "{}; charset=UTF-8".format(filetype))
+            rep.status = falcon.HTTP_200  # This is the default status
+            # for better stream handling provide "wsgi.file_wrapper" in wsgi environ
+            # rep.stream = open(filepath, 'rb')
+            # the following works faster and more consistently than rep.stream above
+            # Maybe Falcon's default is to throttle the reads too much for rep.stream
+            with open(path, 'rb') as f:
+                rep.data = f.read()
+
+
+
+class ServerDoer(doing.Doer):
+    """
+    HTTP WSGI Server Doer
+
+    See Doer for inherited attributes, properties, and methods.
+
+    Attributes:
+       .server is HTTP WSGI Server instance
+
+    Properties:
+
+    """
+
+    def __init__(self, server, **kwa):
+        """
+        Initialize
+
+        Parameters:
+           server is HTTP Server instance
+        """
+        super(ServerDoer, self).__init__(**kwa)
+        self.server = server
+        if self.tymth:
+            self.server.wind(self.tymth)
+
+
+    def wind(self, tymth):
+        """
+        Inject new tymist.tymth as new ._tymth. Changes tymist.tyme base.
+        Updates winds .tymer .tymth
+        """
+        super(ServerDoer, self).wind(tymth)
+        self.server.wind(tymth)
+
+
+    def enter(self):
+        """"""
+        self.server.reopen()
+
+
+    def recur(self, tyme):
+        """"""
+        self.server.service()
+
+
+    def exit(self):
+        """"""
+        self.server.close()
